﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Windows.Media;
using System.Windows;
using System.Globalization;

namespace CAD
{

    public class CADText : CADParent
    {

        private int x, y;  // in mm  Top Left
        private string sText;
        public Color brushText;
        private int angle = 0;

        public int X
        {
            get { return x; }
            set { if (value > 0) x = value; }
        }
        public int Y
        {
            get { return y; }
            set { if (value > 0) y = value; }
        }
        public string Text
        {
            get { return sText; }
            set { sText = value; }
        }

        public int Angle
        {
            get { return angle; }
            set { angle = value; }
        }

        public CADText(int Mousex, int Mousey, string sText)
        {
            this.x = Mousex;
            this.y = Mousey;
            this.sText = sText;
            angle = 0;
            brushText = Colors.Black;
            GraphicTyp = CADParent.GrfTypen.C_TEXT;
        }
        public CADText(int Mousex, int Mousey, int angle, string sText)
        {
            this.x = Mousex;
            this.y = Mousey;
            this.sText = sText;
            this.angle = angle;
            brushText = Colors.Black;
            GraphicTyp = CADParent.GrfTypen.C_TEXT;
        }

        public CADText(CADText text)
        {
            this.x = text.x;
            this.y = text.y;
            this.sText = text.sText;
            brushText = text.brushText;
            GraphicTyp = CADParent.GrfTypen.C_TEXT;
        }

        public CADText()
        {
            this.x = 0;
            this.y = 0;
            this.sText = "";
            brushText = Colors.Black;
            GraphicTyp = CADParent.GrfTypen.C_TEXT;
        }


        public override string ToString()
        {
            return "T: " + x + " / " + y + "   " + sText;
        }

        // Labor4
        public override void draw(DrawingContext dc, double zoom)
        {
            FormattedText formattedText;
            double dFactorMM = 94.5 / 25.4;  // Pixel pro mm
            double dF = dFactorMM * zoom;
            int gx = (int)Math.Round(x * dF);
            int gy = (int)Math.Round(y * dF);
            formattedText = new FormattedText(sText,
                CultureInfo.GetCultureInfo("DE-de"),
                FlowDirection.LeftToRight,
                new Typeface("Verdana"),
                32 * zoom, new SolidColorBrush(brushText)); // text.brushText));   

            if (angle == 0)
            {
                dc.DrawText(formattedText, new Point(gx, gy));
            }
            else
            {
                RotateTransform RT = new RotateTransform(angle, gx, gy);
                dc.PushTransform(RT);
                dc.DrawText(formattedText, new Point(gx, gy));
                dc.Pop();

            }
        }

    }
}
