﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

namespace CAD
{
    /// <summary>
    /// Interaktionslogik für ConsoleDialog.xaml
    /// </summary>
    public partial class ConsoleDialog : Window
    {
        IConsole _parent;
        bool bMultiline = false;
        public ConsoleDialog(IConsole parent)
        {
            InitializeComponent();
            _parent = parent;
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {

        }

        



        private void mnLine_Click(object sender, RoutedEventArgs e)
        {
            if (bMultiline)
                tInputElement.Text += "\r\n"+"L 130, 120, 140, 170";
            else
                tInputElement.Text = "L 130, 120, 140, 170";
        }

        private void mnCircle_Click(object sender, RoutedEventArgs e)
        {
            if (bMultiline)
                tInputElement.Text += "\r\n" + "C 110, 120, 30";
            else
                tInputElement.Text = "C 110, 120, 30";
        }

        private void mnEllipse_Click(object sender, RoutedEventArgs e)
        {
            if (bMultiline)
                tInputElement.Text += "\r\n" + "E 150, 120, 20, 70";
            else
                tInputElement.Text = "E 150, 120, 20, 70";
        }

        private void mnRectangle_Click(object sender, RoutedEventArgs e)
        {
            if (bMultiline)
                tInputElement.Text += "\r\n" + "R 50, 60, 70, 80";
            else
                tInputElement.Text = "R 50, 60, 70, 80";
        }

        private void mnText_Click(object sender, RoutedEventArgs e)
        {
            if (bMultiline)
                tInputElement.Text += "\r\n" + "T 10, 20, Hier ein Text";
            else
                tInputElement.Text = "T 10, 20, Hier ein Text";
        }

        private void mnMultiline_Click(object sender, RoutedEventArgs e)
        {
            mnMultiline.IsChecked = !mnMultiline.IsChecked;
            if (mnMultiline.IsChecked)
            {
                tInputElement.TextWrapping = TextWrapping.Wrap;
                tInputElement.VerticalScrollBarVisibility = ScrollBarVisibility.Visible;
                tInputElement.AcceptsReturn = true;
                bMultiline = true;
                mnInsertMultiline.IsEnabled = true;
                this.Height = 500;
            }
            else
            {
                tInputElement.Text = "";
                tInputElement.TextWrapping = TextWrapping.NoWrap;
                tInputElement.VerticalScrollBarVisibility = ScrollBarVisibility.Hidden;
                tInputElement.AcceptsReturn = false;
                bMultiline = false;
                mnInsertMultiline.IsEnabled = false;
                this.Height = 100;
            }
        }  // mnMultiline_Click

        private void createElement(string sElement)
        {
            CADLine line;
            CADCircle circle;
            CADEllipse ellipse;
            CADRectangle rect;
            CADText text;
            int x1, y1, x2, y2, x, y, w, h, radius, radiusx, radiusy;
            int linewidth = 1;
            int color = 255;

            string sValueUpper = sElement.Trim().ToUpper();
            string sValue = sElement.Trim();
                if (sValue.Length > 5)
                {
                    char cCommand = sValueUpper[0];
                    string sParam = sValue.Substring(1);  // ab 2. zeichen, count from zero
                    string[] sParams = sParam.Split(new Char[] { ',' });
                    /*  "L 10, 20, 100, 300";
                      0: x1
                      1: y1
                      2: x2
                      3: y2
                     */
                    switch (cCommand)
                    {
                        case 'L': 
                            if (!int.TryParse(sParams[0], out x1)) return;
                            if (!int.TryParse(sParams[1], out y1)) return;
                            if (!int.TryParse(sParams[2], out x2)) return;
                            if (!int.TryParse(sParams[3], out y2)) return;
                            if (sParams.Count() > 4)
                            {
                                if (!int.TryParse(sParams[4], out linewidth)) return;
                                line = new CADLine(x1, y1, x2, y2);
                                line.StrokeThickness = linewidth;
                                if (sParams.Count() > 5)
                                {
                                    if (!int.TryParse(sParams[5], out color)) return;
                                    Color colorfill = new Color();
                                    colorfill.R = (byte)((color >> 16) & 0xFF);
                                    colorfill.G = (byte)((color >> 8) & 0xFF);
                                    colorfill.B = (byte)(color & 0xFF);
                                    colorfill.A = 255;
                                    line.BrushLine = colorfill;
                                }
                            }
                            else
                            {
                                line = new CADLine(x1, y1, x2, y2);
                            }
                            _parent.insertCADParent(line);
                            break;
                        case 'R': 
                            if (!int.TryParse(sParams[0], out x1)) return;
                            if (!int.TryParse(sParams[1], out y1)) return;
                            if (!int.TryParse(sParams[2], out w)) return;
                            if (!int.TryParse(sParams[3], out h)) return;
                            if (sParams.Count() > 4)
                            {
                                if (!int.TryParse(sParams[4], out color)) return;
                                rect = new CADRectangle(x1, y1, x1+w, y1+h);
                                if (color < 0)
                                {
                                    rect.brushFill = Colors.Transparent;
                                }
                                else
                                {
                                    Color colorfill = new Color();
                                    colorfill.R = (byte)((color >> 16) & 0xFF);
                                    colorfill.G = (byte)((color >> 8) & 0xFF);
                                    colorfill.B = (byte)(color & 0xFF);
                                    colorfill.A = 255;
                                    rect.brushFill = colorfill;
                                }
                            }
                            else
                            {
                                rect = new CADRectangle(x1, y1, x1 + w, y1 + h);
                            }
                            _parent.insertCADParent(rect);
                            break;
                        case 'C': if (!int.TryParse(sParams[0], out x)) return;
                            if (!int.TryParse(sParams[1], out y)) return;
                            if (!int.TryParse(sParams[2], out radius)) return;
                            circle = new CADCircle(x - radius, y - radius, x + radius, y + radius);
                            _parent.insertCADParent(circle);
                            break;
                        case 'E': if (!int.TryParse(sParams[0], out x)) return;
                            if (!int.TryParse(sParams[1], out y)) return;
                            if (!int.TryParse(sParams[2], out radiusx)) return;
                            if (!int.TryParse(sParams[3], out radiusy)) return;
                            ellipse = new CADEllipse(x - radiusx, y - radiusx, x + radiusx, y + radiusy);
                            _parent.insertCADParent(ellipse);
                            break;
                        case 'T': if (!int.TryParse(sParams[0], out x)) return;
                            if (!int.TryParse(sParams[1], out y)) return;
                            string sText = sParams[2].Trim();
                            if (sText.Length > 0)
                            {
                                text = new CADText(x, y, sText);
                                _parent.insertCADParent(text);
                            }
                            break;
                    }
                }
        }

        private void TextBox_KeyDown(object sender, KeyEventArgs e)
        {
            if ( (e.Key == Key.Return) && (!bMultiline) )
            {
                // nun senden
                createElement(tInputElement.Text);

            }
        }

        private void mnInsertMultiline_Click(object sender, RoutedEventArgs e)
        {
            string sValue = tInputElement.Text.Trim();
            string[] sParams = sValue.Split(new string[] { "\r\n" }, StringSplitOptions.RemoveEmptyEntries);  // ','
            int n = sParams.Count();
            n = sParams.Count();
            foreach (string sParam in sParams)
            {
                createElement(sParam);
            }
        }

        private void mainSamples_Click(object sender, RoutedEventArgs e)
        {
            if (!mnMultiline.IsChecked)
            {
                mnMultiline.IsChecked = true;
                tInputElement.TextWrapping = TextWrapping.Wrap;
                tInputElement.VerticalScrollBarVisibility = ScrollBarVisibility.Visible;
                tInputElement.AcceptsReturn = true;
                bMultiline = true;
                mnInsertMultiline.IsEnabled = true;
                this.Height = 500;
            }

            if (e.OriginalSource == mnHausDesNikolaus1)
            {
                tInputElement.Text = "R 10, 50, 40, 30" + "\r\n" +
                                        "L 10, 50, 60, 80" + "\r\n" +
                                        "L 10, 80, 60, 50" + "\r\n" +

                                        "L 10, 50, 35, 35" + "\r\n" +
                                        "L 35, 35, 60, 50" + "\r\n";
            }
            if (e.OriginalSource == mnHausDesNikolaus2)
            {
                tInputElement.Text = "R 100, 100, 500, 300" + "\r\n" +
                                        "L 100, 100, 600, 400" + "\r\n" +
                                        "L 100, 400, 600, 100" + "\r\n" +

                                        "L 100, 100, 350, 50" + "\r\n" +
                                        "L 350, 50, 600, 100" + "\r\n";
            }
            if (e.OriginalSource == mnGrundriss)
            {
                tInputElement.Text = "R 50, 50, 1000, 700, -1" + "\r\n" +  // x/y   width height
                                    "L 50, 50, 400, 50, 9" + "\r\n" +
                                    "L 470, 50, 700, 50, 9" + "\r\n" +
                                    "L 900, 50, 1050, 50, 9" + "\r\n" +

                                    "L 1050, 50, 1050, 500, 9" + "\r\n" +
                                    "L 1050, 570, 1050, 750, 9" + "\r\n" +

                                    "L 50, 750, 350, 750, 9" + "\r\n" +
                                    "L 420, 750, 580, 750, 9" + "\r\n" +
                                    "L 650, 750, 800, 750, 9" + "\r\n" +

                                    "L 800, 750, 1050, 750, 9" + "\r\n" +

                                    "L 350, 50, 350, 400, 9" + "\r\n" +
                                    "L 600, 50, 600, 400, 9" + "\r\n" +

                                    "L 50, 400, 200, 400, 9" + "\r\n" +
                                    "L 270, 400, 400, 400, 9" + "\r\n" +
                                    "L 470, 400, 650, 400, 9" + "\r\n" +
                                    "L 720, 400, 1050, 400, 9" + "\r\n" +

                                    "L 800, 400, 800, 600, 9" + "\r\n" +
                                    "L 800, 670, 800, 750, 9" + "\r\n" +

                                    "L 50, 500, 350, 500, 9" + "\r\n" +
                                    "L 420, 500, 500, 500, 9" + "\r\n" +

                                    "L 500, 500, 500, 750,  9" + "\r\n" +

                                    "L 50, 50, 50, 200, 9" + "\r\n" +
                                    "L 50, 270, 50, 750, 9" + "\r\n" +

                                    "T 50, 270, 50, 750, 9" + "\r\n" +
                                        "\r\n";
                                      
            }
            if (e.OriginalSource == mnLines10000)
            {
                int x1, x2, y1, y2;
                int color;
                string sText = "";
                Random rnd = new Random();
                for (int i = 0; i < 10000; i++)
                {
                    x1 = (int)(rnd.NextDouble() * 1700);
                    x2 = (int)(rnd.NextDouble() * 1700);
                    y1 = (int)(rnd.NextDouble() * 1700);
                    y2 = (int)(rnd.NextDouble() * 1700);
                    color = (int)(rnd.NextDouble() * 0xFFFFFF);                    
                    sText += "L " + x1 + ", " + y1 + ", " + x2 + ", " + y2 + ", 1, " + color+"\r\n";
                }
                tInputElement.Text = sText;
            }
            if (e.OriginalSource == mnLines10000_2)
            {
                StringBuilder sText = new StringBuilder();
                int x1, x2, y1, y2;
                int color;
                sText.Clear();
                Random rnd = new Random();
                for (int i = 0; i < 10000; i++)
                {
                    x1 = (int)(rnd.NextDouble() * 1700);
                    x2 = (int)(rnd.NextDouble() * 1700);
                    y1 = (int)(rnd.NextDouble() * 1700);
                    y2 = (int)(rnd.NextDouble() * 1700);
                    color = (int)(rnd.NextDouble() * 0xFFFFFF);
                    sText.AppendLine("L " + x1 + ", " + y1 + ", " + x2 + ", " + y2 + ", 1, " + color);
                }
                tInputElement.Text = sText.ToString();
            }

            if (e.OriginalSource == mnRectangles10000)
            {
                StringBuilder sText = new StringBuilder();
                int x, y, w, h;
                int color;
                sText.Clear();
                Random rnd = new Random();
                for (int i = 0; i < 10000; i++)
                {
                    x = (int)(rnd.NextDouble() * 1700);
                    y = (int)(rnd.NextDouble() * 1700);
                    w = (int)(rnd.NextDouble() * 500);
                    h = (int)(rnd.NextDouble() * 800);
                    color = (int)(rnd.NextDouble() * 0xFFFFFF);
                    sText.AppendLine("R " + x + ", " + y + ", " + w + ", " + h + ", " + color);
                }
                tInputElement.Text = sText.ToString();
            }

            
        }// mainSamples_Click



        private void mnDeleteElements_Click(object sender, RoutedEventArgs e)
        {
            _parent.deleteElements();
        } 



    }
}
