﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

// neu
using System.Globalization;


namespace CAD
{
    /// <summary>
    /// Interaktionslogik für EditCircle.xaml
    /// </summary>
    public partial class EditCircle : Window
    {
        private  CADCircle _circle;

        private bool bRetCode = false;
        // bool bStart = true;

        public bool Retcode
        {
            get { return bRetCode; }
        }

        public CADCircle Circle
        {
            get { return _circle; }
        }


        public EditCircle(CADCircle circle)
        {
            InitializeComponent();
            _circle = circle;
            setGUI();
        }

        private void setGUI()
        {
            cbLineStyle.Items.Clear();
            cbLineStyle.Items.Add("Dash");
            cbLineStyle.Items.Add("DashDot");
            cbLineStyle.Items.Add("DashDotDot");
            cbLineStyle.Items.Add("Dot");
            cbLineStyle.Items.Add("Solid");

            tInputX.Text = _circle.X.ToString();
            tInputY.Text = _circle.Y.ToString();
            tInputRadius.Text = _circle.Radius.ToString();
            
            cbLineStyle.SelectedIndex = 0;
            if (_circle.LineStyle == DashStyles.Dash) cbLineStyle.SelectedIndex = 0;
            if (_circle.LineStyle == DashStyles.DashDot) cbLineStyle.SelectedIndex = 1;
            if (_circle.LineStyle == DashStyles.DashDotDot) cbLineStyle.SelectedIndex = 2;
            if (_circle.LineStyle == DashStyles.Dot) cbLineStyle.SelectedIndex = 3;
            if (_circle.LineStyle == DashStyles.Solid) cbLineStyle.SelectedIndex = 4;
                       
            colorCanvas.Background = new SolidColorBrush(_circle.brushLine);

            colorContentCanvas.Background = new SolidColorBrush(_circle.brushFill);

            tInputLinewidth.Text = _circle.StrokeThickness.ToString("0.0", System.Globalization.CultureInfo.InvariantCulture);

        }

        private void bnOk_Click(object sender, RoutedEventArgs e)
        {
            int iValue = 0;
            double dValue = 0.0;
            bool bcanConvert;
            bcanConvert = int.TryParse(tInputX.Text, out iValue);
            if (bcanConvert)
            {
                _circle.X = iValue;
            }

            bcanConvert = int.TryParse(tInputY.Text, out iValue);
            if (bcanConvert)
            {
                _circle.Y = iValue;
            }


            bcanConvert = int.TryParse(tInputRadius.Text, out iValue);
            if (bcanConvert)
            {
                _circle.Radius = iValue;
            }


            NumberStyles style = NumberStyles.AllowDecimalPoint;
            string sValue = tInputLinewidth.Text.Trim().Replace(",", ".");
            bcanConvert = double.TryParse(sValue, style, System.Globalization.CultureInfo.InvariantCulture, out dValue);
            if (bcanConvert)
            {
                _circle.StrokeThickness = dValue;
            }


            switch (cbLineStyle.SelectedIndex)
            {
                case 0: _circle.LineStyle = DashStyles.Dash;
                    break;
                case 1: _circle.LineStyle = DashStyles.DashDot;
                    break;
                case 2: _circle.LineStyle = DashStyles.DashDotDot;
                    break;
                case 3: _circle.LineStyle = DashStyles.Dot;
                    break;
                case 4: _circle.LineStyle = DashStyles.Solid;
                    break;
            }
            bRetCode = true;
            Close();
        }

        private void bnCancel_Click(object sender, RoutedEventArgs e)
        {
            Close();
        }

        private void bnColor_Click(object sender, RoutedEventArgs e)
        {
            ColorDialog dialog = new ColorDialog();
            dialog.setColor(_circle.brushLine);
            dialog.ShowDialog();
            if (dialog.Retcode)
            {
                _circle.brushLine = Color.FromArgb(dialog.Alpha, dialog.Red, dialog.Green, dialog.Blue);
                colorCanvas.Background = new SolidColorBrush(_circle.brushLine);
            }

        }

        private void bnColorContent_Click(object sender, RoutedEventArgs e)
        {
            ColorDialog dialog = new ColorDialog();
            dialog.setColor(_circle.brushFill);
            dialog.ShowDialog();
            if (dialog.Retcode)
            {
                _circle.brushFill = Color.FromArgb(dialog.Alpha, dialog.Red, dialog.Green, dialog.Blue);
                colorContentCanvas.Background = new SolidColorBrush(_circle.brushFill);
            }
        }

    }
}
