﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

// neu
using System.Globalization;

namespace CAD
{
    /// <summary>
    /// Interaktionslogik für EditEllipse.xaml
    /// </summary>
    public partial class EditEllipse : Window
    {
        private  CADEllipse _ellipse;

        private bool bRetCode = false;
        // bool bStart = true;

        public bool Retcode
        {
            get { return bRetCode; }
        }

        public CADEllipse Ellipse
        {
            get { return _ellipse; }
        }


        public EditEllipse(CADEllipse ellipse)
        {
            InitializeComponent();
            _ellipse = ellipse;
            setGUI();
        }

        private void setGUI()
        {
            cbLineStyle.Items.Clear();
            cbLineStyle.Items.Add("Dash");
            cbLineStyle.Items.Add("DashDot");
            cbLineStyle.Items.Add("DashDotDot");
            cbLineStyle.Items.Add("Dot");
            cbLineStyle.Items.Add("Solid");

            tInputX.Text = _ellipse.X.ToString();
            tInputY.Text = _ellipse.Y.ToString();
            tInputRadiusX.Text = _ellipse.RadiusX.ToString();
            tInputRadiusY.Text = _ellipse.RadiusY.ToString();
            
            cbLineStyle.SelectedIndex = 0;
            if (_ellipse.LineStyle == DashStyles.Dash) cbLineStyle.SelectedIndex = 0;
            if (_ellipse.LineStyle == DashStyles.DashDot) cbLineStyle.SelectedIndex = 1;
            if (_ellipse.LineStyle == DashStyles.DashDotDot) cbLineStyle.SelectedIndex = 2;
            if (_ellipse.LineStyle == DashStyles.Dot) cbLineStyle.SelectedIndex = 3;
            if (_ellipse.LineStyle == DashStyles.Solid) cbLineStyle.SelectedIndex = 4;
                       
            colorCanvas.Background = new SolidColorBrush(_ellipse.brushLine);

            colorContentCanvas.Background = new SolidColorBrush(_ellipse.brushFill);

            tInputLinewidth.Text = _ellipse.StrokeThickness.ToString("0.0", System.Globalization.CultureInfo.InvariantCulture);

        }

        private void bnOk_Click(object sender, RoutedEventArgs e)
        {
            int iValue = 0;
            double dValue = 0.0;
            bool bcanConvert;
            bcanConvert = int.TryParse(tInputX.Text, out iValue);
            if (bcanConvert)
            {
                _ellipse.X = iValue;
            }

            bcanConvert = int.TryParse(tInputY.Text, out iValue);
            if (bcanConvert)
            {
                _ellipse.Y = iValue;
            }


            bcanConvert = int.TryParse(tInputRadiusX.Text, out iValue);
            if (bcanConvert)
            {
                _ellipse.RadiusX = iValue;
            }
            bcanConvert = int.TryParse(tInputRadiusY.Text, out iValue);
            if (bcanConvert)
            {
                _ellipse.RadiusY = iValue;
            }


            NumberStyles style = NumberStyles.AllowDecimalPoint;
            string sValue = tInputLinewidth.Text.Trim().Replace(",", ".");
            bcanConvert = double.TryParse(sValue, style, System.Globalization.CultureInfo.InvariantCulture, out dValue);
            if (bcanConvert)
            {
                _ellipse.StrokeThickness = dValue;
            }


            switch (cbLineStyle.SelectedIndex)
            {
                case 0: _ellipse.LineStyle = DashStyles.Dash;
                    break;
                case 1: _ellipse.LineStyle = DashStyles.DashDot;
                    break;
                case 2: _ellipse.LineStyle = DashStyles.DashDotDot;
                    break;
                case 3: _ellipse.LineStyle = DashStyles.Dot;
                    break;
                case 4: _ellipse.LineStyle = DashStyles.Solid;
                    break;
            }
            bRetCode = true;
            Close();
        }

        private void bnCancel_Click(object sender, RoutedEventArgs e)
        {
            Close();
        }

        private void bnColor_Click(object sender, RoutedEventArgs e)
        {
            ColorDialog dialog = new ColorDialog();
            dialog.setColor(_ellipse.brushLine);
            dialog.ShowDialog();
            if (dialog.Retcode)
            {
                _ellipse.brushLine = Color.FromArgb(dialog.Alpha, dialog.Red, dialog.Green, dialog.Blue);
                colorCanvas.Background = new SolidColorBrush(_ellipse.brushLine);
            }

        }

        private void bnColorContent_Click(object sender, RoutedEventArgs e)
        {
            ColorDialog dialog = new ColorDialog();
            dialog.setColor(_ellipse.brushFill);
            dialog.ShowDialog();
            if (dialog.Retcode)
            {
                _ellipse.brushFill = Color.FromArgb(dialog.Alpha, dialog.Red, dialog.Green, dialog.Blue);
                colorContentCanvas.Background = new SolidColorBrush(_ellipse.brushFill);
            }
        }

    }
}
