﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

// neu
using System.Globalization;

namespace CAD
{
    /// <summary>
    /// Interaktionslogik für EditLine.xaml
    /// </summary>
    public partial class EditLine : Window
    {
        CADLine _line;

        private bool bRetCode = false;
        // bool bStart = true;

        public bool Retcode
        {
            get { 
                return bRetCode; 
            }
        }

        public CADLine Line
        {
            get { return _line; }
        }


        public EditLine(CADLine line)
        {
            InitializeComponent();
            _line = line;
            setGUI();
        }

        private void setGUI()
        {
            cbLineStyle.Items.Clear();
            cbLineStyle.Items.Add("Dash");
            cbLineStyle.Items.Add("DashDot");
            cbLineStyle.Items.Add("DashDotDot");
            cbLineStyle.Items.Add("Dot");
            cbLineStyle.Items.Add("Solid");

            tInputX1.Text = _line.X1.ToString();
            tInputY1.Text = _line.Y1.ToString();
            tInputX2.Text = _line.X2.ToString();
            tInputY2.Text = _line.Y2.ToString();

            cbLineStyle.SelectedIndex = 0;
            if (_line.LineStyle == DashStyles.Dash) cbLineStyle.SelectedIndex = 0;
            if (_line.LineStyle == DashStyles.DashDot) cbLineStyle.SelectedIndex = 1;
            if (_line.LineStyle == DashStyles.DashDotDot) cbLineStyle.SelectedIndex = 2;
            if (_line.LineStyle == DashStyles.Dot) cbLineStyle.SelectedIndex = 3;
            if (_line.LineStyle == DashStyles.Solid) cbLineStyle.SelectedIndex = 4;
                       
            colorCanvas.Background = new SolidColorBrush(_line.BrushLine);

            tInputLinewidth.Text = _line.StrokeThickness.ToString("0.0", System.Globalization.CultureInfo.InvariantCulture);

        }

        private void bnOk_Click(object sender, RoutedEventArgs e)
        {            
            int iValue = 0;
            double dValue = 0.0;
            bool bcanConvert;
            bcanConvert = int.TryParse(tInputX1.Text, out iValue);
            if (bcanConvert)
            {
                _line.X1 = iValue;
            }

            bcanConvert = int.TryParse(tInputY1.Text, out iValue);
            if (bcanConvert)
            {
                _line.Y1 = iValue;
            }

            bcanConvert = int.TryParse(tInputX2.Text, out iValue);
            if (bcanConvert)
            {
                _line.X2 = iValue;
            }

            bcanConvert = int.TryParse(tInputY2.Text, out iValue);
            if (bcanConvert)
            {
                _line.Y2 = iValue;
            }

            // System.Globalization.CultureInfo.InvariantCulture

            NumberStyles style = NumberStyles.AllowDecimalPoint;
            string sValue = tInputLinewidth.Text.Trim().Replace(",", ".");
            bcanConvert = double.TryParse(sValue, style, System.Globalization.CultureInfo.InvariantCulture, out dValue);
            if (bcanConvert)
            {                
                _line.StrokeThickness = dValue;
            }


            switch (cbLineStyle.SelectedIndex)
            {
                case 0: _line.LineStyle = DashStyles.Dash;
                    break;
                case 1: _line.LineStyle = DashStyles.DashDot;
                    break;
                case 2: _line.LineStyle = DashStyles.DashDotDot;
                    break;
                case 3: _line.LineStyle = DashStyles.Dot;
                    break;
                case 4: _line.LineStyle = DashStyles.Solid;
                    break;
            }
            bRetCode = true;
            Close();
        }

        private void bnCancel_Click(object sender, RoutedEventArgs e)
        {
            Close();
        }

        private void bnColor_Click(object sender, RoutedEventArgs e)
        {
            ColorDialog dialog = new ColorDialog();
            dialog.setColor(_line.BrushLine);
            dialog.ShowDialog();
            if (dialog.Retcode)
            {
                _line.BrushLine = Color.FromArgb(dialog.Alpha, dialog.Red, dialog.Green, dialog.Blue);
                colorCanvas.Background = new SolidColorBrush(_line.BrushLine);
            }

        }
    }
}
